@@ -280,6 +280,20 @@ different sets of packages."""
               "the default behavior, but will change in conda-build 4.0."),
         default=cc_conda_build.get('error_overlinking', 'false').lower() == 'true',
     )
+    p.add_argument(
+        "--error-overdepending", dest='error_overdepending', action="store_true",
+        help=("Enable error when packages with names beginning `lib` or which have "
+              "`run_exports` are not auto-loaded by the OSes DSO loading mechanism by "
+              "any of the files in this package."),
+        default=cc_conda_build.get('error_overdepending', 'false').lower() == 'true',
+    )
+    p.add_argument(
+        "--no-error-overdepending", dest='error_overdepending', action="store_false",
+        help=("Disable error when packages with names beginning `lib` or which have "
+              "`run_exports` are not auto-loaded by the OSes DSO loading mechanism by "
+              "any of the files in this package."),
+        default=cc_conda_build.get('error_overdepending', 'false').lower() == 'true',
+    )
     p.add_argument(
         "--long-test-prefix", action="store_true",
         help=("Use a long prefix for the test prefix, as well as the build prefix.  Affects only "
@@ -357,7 +371,7 @@ def check_action(recipe, config):
 
 
 def execute(args):
-    parser, args = parse_args(args)
+    _parser, args = parse_args(args)
     config = Config(**args.__dict__)
     build.check_external()
 
