@@ -252,10 +252,11 @@ def pin_compatible(m, package_name, lower_bound=None, upper_bound=None, min_pin=
                     else:
                         compatibility = apply_pin_expressions(version, min_pin, max_pin)
 
-    if (not compatibility and not permit_undefined_jinja and not bypass_env_check and
-            'pin_compatible' in m.extract_requirements_text()):
-        raise RuntimeError("Could not get compatibility information for {} package.  "
-                           "Is it one of your host dependencies?".format(package_name))
+    if (not compatibility and not permit_undefined_jinja and not bypass_env_check):
+        check = re.compile(r'pin_compatible\s*\(\s*[''"]{}[''"]'.format(package_name))
+        if check.search(m.extract_requirements_text()):
+            raise RuntimeError("Could not get compatibility information for {} package.  "
+                               "Is it one of your host dependencies?".format(package_name))
     return " ".join((package_name, compatibility)) if compatibility is not None else package_name
 
 
