@@ -168,6 +168,7 @@ class DummyPsutilProcess(object):
     def children(self, *args, **kwargs):
         return []
 
+
 def _setup_rewrite_pipe(env):
     """Rewrite values of env variables back to $ENV in stdout
 
@@ -194,15 +195,22 @@ def _setup_rewrite_pipe(env):
 
     def rewriter():
         while True:
-            line = r.readline()
-            if not line:
-                # reading done
-                r.close()
-                os.close(w_fd)
-                return
-            for s, key in replacements.items():
-                line = line.replace(s, replacement_t.format(key))
-            sys.stdout.write(line)
+            try:
+                line = r.readline()
+                if not line:
+                    # reading done
+                    r.close()
+                    os.close(w_fd)
+                    return
+                for s, key in replacements.items():
+                    line = line.replace(s, replacement_t.format(key))
+                sys.stdout.write(line)
+            except UnicodeDecodeError:
+                try:
+                    txt = os.read(r, 10000)
+                    sys.stdout.write(txt or '')
+                except TypeError:
+                    pass
 
     t = Thread(target=rewriter)
     t.daemon = True
@@ -987,9 +995,8 @@ def convert_path_for_cygwin_or_msys2(exe, path):
 
 
 def get_skip_message(m):
-    recipe_dir = m.path or m.meta.get('extra', {}).get('parent_recipe', {}).get('path')
     return ("Skipped: {} from {} defines build/skip for this configuration ({}).".format(
-        m.name(), recipe_dir,
+        m.name(), m.path,
         {k: m.config.variant[k] for k in m.get_used_vars()}))
 
 
@@ -1015,7 +1022,7 @@ def package_has_file(package_path, file_path):
 
 def ensure_list(arg):
     if (isinstance(arg, string_types) or not hasattr(arg, '__iter__')):
-        if arg:
+        if arg is not None:
             arg = [arg]
         else:
             arg = []
@@ -1052,7 +1059,7 @@ def expand_globs(path_list, root_dir):
             files.extend(glob_files)
     prefix_path_re = re.compile('^' + re.escape('%s%s' % (root_dir, os.path.sep)))
     files = [prefix_path_re.sub('', f, 1) for f in files]
-    return files
+    return sorted(files)
 
 
 def find_recipe(path):
@@ -1438,36 +1445,39 @@ def _equivalent(base_value, value, path):
     return equivalent
 
 
-def merge_or_update_dict(base, new, path="", merge=True, raise_on_clobber=False):
+def merge_or_update_dict(base, new, path="", merge=True, raise_on_clobber=False, add_missing_keys=True):
+    if base == new:
+        return base
     log = get_logger(__name__)
     for key, value in new.items():
-        base_value = base.get(key, value)
-        if hasattr(value, 'keys'):
-            base_value = merge_or_update_dict(base_value, value, path, merge,
-                                              raise_on_clobber=raise_on_clobber)
-            base[key] = base_value
-        elif hasattr(value, '__iter__') and not isinstance(value, string_types):
-            if merge:
-                if base_value != value:
+        if key in base or add_missing_keys:
+            base_value = base.get(key, value)
+            if hasattr(value, 'keys'):
+                base_value = merge_or_update_dict(base_value, value, path, merge,
+                                                raise_on_clobber=raise_on_clobber)
+                base[key] = base_value
+            elif hasattr(value, '__iter__') and not isinstance(value, string_types):
+                if merge:
+                    if base_value != value:
+                        try:
+                            base_value.extend(value)
+                        except TypeError:
+                            base_value = value
                     try:
-                        base_value.extend(value)
+                        base[key] = list(base_value)
                     except TypeError:
-                        base_value = value
-                try:
-                    base[key] = list(base_value)
-                except TypeError:
-                    base[key] = base_value
+                        base[key] = base_value
+                else:
+                    base[key] = value
             else:
-                base[key] = value
-        else:
-            if (base_value and merge and not _equivalent(base_value, value, path) and
-                    raise_on_clobber):
-                log.debug('clobbering key {} (original value {}) with value {}'.format(key,
-                                                                            base_value, value))
-            if value is None:
-                del base[key]
-            else:
-                base[key] = value
+                if (base_value and merge and not _equivalent(base_value, value, path) and
+                        raise_on_clobber):
+                    log.debug('clobbering key {} (original value {}) with value {}'.format(key,
+                                                                                base_value, value))
+                if value is None and key in base:
+                    del base[key]
+                else:
+                    base[key] = value
     return base
 
 
@@ -1578,7 +1588,7 @@ spec_ver_needing_star_re = re.compile("^([0-9a-zA-Z\.]+)$")
 
 def ensure_valid_spec(spec, warn=False):
     if isinstance(spec, MatchSpec):
-        if (hasattr(spec, 'version') and spec.version and (not hasattr(spec, 'build') or spec.build) and
+        if (hasattr(spec, 'version') and spec.version and (not spec.get('build', '')) and
                 spec_ver_needing_star_re.match(str(spec.version))):
             if str(spec.name) not in ('python', 'numpy') or str(spec.version) != 'x.x':
                 spec = MatchSpec("{} {}".format(str(spec.name), str(spec.version) + '.*'))
